@@ -1,12 +1,12 @@
 import sys
-from logging import Logger
 from pathlib import Path
+from typing import Optional
 
 from ..repository import NumerousRepository
 from ..utils import bold, green, print_repository_help_message, red
 
 
-def command_init(log: Logger, path: Path):
+def command_init(path: Optional[Path]):
     path = path or Path.cwd()
 
     if (path / NumerousRepository.FILE_NAME).exists():
