@@ -10,7 +10,7 @@ class RepositoryRemote:
                  job_id: Optional[str] = None, name: Optional[str] = None):
         if name is not None and api_url is not None and job_id is not None:
             self.name = name
-            self.api_url = name
+            self.api_url = api_url
             self.job_id = job_id
         elif url is not None:
             parsed_url = urlparse(url)
